@@ -24,6 +24,8 @@ import org.ovirt.engine.core.utils.transaction.TransactionSupport;
 @NonTransactiveCommandAttribute(forceCompensation = true)
 public class RemoveNetworkCommand<T extends RemoveNetworkParameters> extends NetworkCommon<T> {
 
+    @Inject
+    private NetworkHelper networkHelper;
     @Inject
     private NetworkClusterHelper networkClusterHelper;
 
@@ -62,6 +64,7 @@ public class RemoveNetworkCommand<T extends RemoveNetworkParameters> extends Net
         TransactionSupport.executeInNewTransaction(() -> {
             removeVnicProfiles();
             removeFromClusters();
+            networkHelper.setVdsmNamesInVdsInterfaces(getNetwork());
             getCompensationContext().snapshotEntity(getNetwork());
             networkDao.remove(getNetwork().getId());
             getCompensationContext().stateChanged();
