@@ -2,36 +2,34 @@ package org.ovirt.engine.core.bll.network;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyList;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
-import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
-import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.verifyZeroInteractions;
 import static org.mockito.Mockito.when;
 
 import java.util.Arrays;
 import java.util.List;
+import java.util.stream.Collectors;
 
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
-import org.mockito.verification.VerificationMode;
 import org.ovirt.engine.core.bll.context.NoOpCompensationContext;
 import org.ovirt.engine.core.bll.network.macpool.MacPool;
 import org.ovirt.engine.core.common.AuditLogType;
 import org.ovirt.engine.core.common.businessentities.network.VmNic;
-import org.ovirt.engine.core.common.osinfo.OsRepository;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.compat.Version;
 import org.ovirt.engine.core.dal.dbbroker.auditloghandling.AuditLogableBase;
 import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.network.VmNetworkInterfaceDao;
 import org.ovirt.engine.core.dao.network.VmNetworkStatisticsDao;
 import org.ovirt.engine.core.dao.network.VmNicDao;
+import org.ovirt.engine.core.di.InjectorRule;
 import org.ovirt.engine.core.utils.RandomUtils;
 
 @RunWith(MockitoJUnitRunner.class)
@@ -41,6 +39,9 @@ public class VmInterfaceManagerTest {
     private static final String VM_NAME = "vmName";
     private static final int OS_ID = 0;
 
+    @Rule
+    public InjectorRule injectorRule = new InjectorRule();
+
     @Mock
     private MacPool macPool;
 
@@ -61,9 +62,6 @@ public class VmInterfaceManagerTest {
 
     private VmInterfaceManager vmInterfaceManager;
 
-    @Mock
-    private Version version;
-
     @Before
     @SuppressWarnings("unchecked")
     public void setupMocks() {
@@ -80,29 +78,29 @@ public class VmInterfaceManagerTest {
 
     @Test
     public void add() {
-        runAddAndVerify(createNewInterface(), false, times(0), OS_ID);
+        runAddAndVerify(createNewInterface(), true);
     }
 
     @Test
     public void addWithExistingMacAddressSucceed() {
-        VmNic iface = createNewInterface();
-        runAddAndVerify(iface, true, times(1), OS_ID);
+        runAddAndVerify(createNewInterface(), false);
     }
 
-    protected void runAddAndVerify(VmNic iface,
-            boolean reserveExistingMac,
-            VerificationMode addMacVerification,
-            int osId) {
-        OsRepository osRepository = mock(OsRepository.class);
-        when(vmInterfaceManager.getOsRepository()).thenReturn(osRepository);
-        when(osRepository.hasNicHotplugSupport(any(Integer.class), any(Version.class))).thenReturn(true);
-        vmInterfaceManager.add(iface, NoOpCompensationContext.getInstance(), reserveExistingMac, false, osId, version);
-        if (reserveExistingMac) {
-            verify(macPool, times(1)).forceAddMac(iface.getMacAddress());
-        } else {
-            verifyZeroInteractions(macPool);
+    protected void runAddAndVerify(VmNic iface, boolean reassignMac) {
+        if (!reassignMac) {
+            //we need to mock successful addition of MAC to pool, otherwise error is thrown
+            when(macPool.addMac(eq(iface.getMacAddress()))).thenReturn(true);
         }
-        verifyAddDelegatedCorrectly(iface, addMacVerification);
+
+        vmInterfaceManager.add(iface, NoOpCompensationContext.getInstance(), reassignMac);
+        if (reassignMac) {
+            verify(macPool).allocateNewMac();
+        } else {
+            verify(macPool).addMac(iface.getMacAddress());
+        }
+
+        verify(vmNicDao).save(iface);
+        verify(vmNetworkStatisticsDao).save(iface.getStatistics());
     }
 
 
@@ -113,37 +111,14 @@ public class VmInterfaceManagerTest {
 
         when(vmNicDao.getAllForVm(any(Guid.class))).thenReturn(interfaces);
 
-        vmInterfaceManager.removeAll(Guid.newGuid());
+        vmInterfaceManager.removeAllAndReleaseMacAddresses(Guid.newGuid());
 
         for (VmNic iface : interfaces) {
-            verifyRemoveAllDelegatedCorrectly(iface);
+            verify(vmNicDao).remove(iface.getId());
+            verify(vmNetworkStatisticsDao).remove(iface.getId());
         }
-    }
 
-    /**
-     * Verify that {@link VmInterfaceManager#add} delegated correctly to {@link MacPool} & Daos.
-     *
-     * @param iface
-     *            The interface to check for.
-     * @param addMacVerification
-     *            Mode to check (times(1), never(), etc) for {@link MacPool#addMac(String)}.
-     */
-    protected void verifyAddDelegatedCorrectly(VmNic iface, VerificationMode addMacVerification) {
-        verify(macPool, addMacVerification).forceAddMac(iface.getMacAddress());
-        verify(vmNicDao).save(iface);
-        verify(vmNetworkStatisticsDao).save(iface.getStatistics());
-    }
-
-    /**
-     * Verify that {@link VmInterfaceManager#removeAll} delegated correctly to {@link MacPool} & Daos.
-     *
-     * @param iface
-     *            The interface to check for.
-     */
-    protected void verifyRemoveAllDelegatedCorrectly(VmNic iface) {
-        verify(macPool, times(1)).freeMac(iface.getMacAddress());
-        verify(vmNicDao).remove(iface.getId());
-        verify(vmNetworkStatisticsDao).remove(iface.getId());
+        verify(macPool).freeMacs(interfaces.stream().map(VmNic::getMacAddress).collect(Collectors.toList()));
     }
 
     /**
