@@ -7,7 +7,6 @@ import org.ovirt.engine.core.common.job.JobExecutionStatus;
 import org.ovirt.engine.ui.common.presenter.popup.DefaultConfirmationPopupPresenterWidget;
 import org.ovirt.engine.ui.common.uicommon.model.SearchableTabModelProvider;
 import org.ovirt.engine.ui.uicommonweb.models.events.TaskListModel;
-
 import com.google.gwt.event.shared.EventBus;
 import com.google.inject.Inject;
 import com.google.inject.Provider;
@@ -59,13 +58,8 @@ public class TaskModelProvider extends SearchableTabModelProvider<Job, TaskListM
     }
 
     @Override
-    public TaskListModel getModel() {
-        return getCommonModel().getTaskList();
-    }
-
-    @Override
-    protected void onCommonModelChange() {
-        super.onCommonModelChange();
+    protected void initializeModelHandlers(TaskListModel model) {
+        super.initializeModelHandlers(model);
         if (taskHandler != null) {
             taskHandler.updateTree();
         }
